from LibHanger.Library.uwGlobals import globalValues
from Stabdifspy.Library.StabdifspyConfig import StabdifspyConfig

class StabdifspyGlobal(globalValues):
    
    def __init__(self):
        
        """
        コンストラクタ
        """
        
        # 基底側コンストラクタ呼び出し
        super().__init__()

        self.StabdifspyConfig:StabdifspyConfig = None
        """ Stabdifspy共通設定 """

# インスタンス生成(import時に実行される)
gvStab = StabdifspyGlobal()



from LibHanger.Library.uwConfig import cmnConfig

class StabdifspyConfig(cmnConfig):
    
    """
    Stabdifspy共通設定クラス(RolexReserverConfig)
    """ 
    
    class settingValueStruct(cmnConfig.settingValueStruct):

        """
        設定値構造体
        """ 

    def __init__(self):
        
        """
        コンストラクタ
        """
        
        # 基底側コンストラクタ
        super().__init__()
        
        self.stableDiffusionSiteUrl = ''
        """ StableDiffusion Site URL """
        
        self.endpointTxt2Img = ''
        """ EndPoint txt2img """
        
        self.outputDirName = ''
        """ Pic Output directoryName """
        
        self.outputFileNameFormat = ''
        """ Pic Output filename format """
        
        self.processAbortFile = 'stopper.txt'
        """ process abort file """

        # 設定ファイル名追加
        self.setConfigFileName('Stabdifspy.ini')
        
    def getConfig(self, _scriptFilePath: str, configFileDir: str = ''):
        
        """ 
        設定ファイルを読み込む 
        
        Parameters
        ----------
        _scriptFilePath : str
            スクリプトファイルパス
        configFileDir : str
            設定ファイルの格納場所となるディレクトリ
        """

        # 基底側のiniファイル読込
        super().getConfig(_scriptFilePath, configFileDir)
        
    def setInstanceMemberValues(self):
        
        """ 
        インスタンス変数に読み取った設定値をセットする
        """
        
        # 基底側実行
        super().setInstanceMemberValues()
        
        # StableDiffusion Site URL
        self.setConfigValue('stableDiffusionSiteUrl',self.config_ini,'SITE','STABLEDIFFUSION_SITE_URL',str)

        # EndPoint txt2img
        self.setConfigValue('endpointTxt2Img',self.config_ini,'ENDPOINT','TXT2IMG',str)

        # Pic Output directoryName
        self.setConfigValue('outputDirName',self.config_ini,'DIR','OUTPUT_DIR',str)
        
        # Pic FileName format
        self.setConfigValue('outputFileNameFormat',self.config_ini,'DEFAULT','OUTPUT_FILE_FORMAT',str)
        
        # process abort file
        self.setConfigValue('processAbortFile',self.config_ini,'ABORT','PROCESS_ABORT_FILE',str)
        


import os
import requests
import base64
import time

class GeStab():
    """
    GeStabクラス
    """
    
    def __init__(self, _gv, _rootPath) -> None:
        """
        コンストラクタ
        """

        # ルートパスを取得
        self.rootPath = _rootPath

        # 共通設定取得
        self.gv = _gv
        
    def generatePicture(self):
        """
        画像生成
        """
        
        # Get - response
        response = requests.post(url=self.gv.StabdifspyConfig.stableDiffusionSiteUrl + self.gv.StabdifspyConfig.endpointTxt2Img , json=self.getPayload())

        # parametersをログ出力
        print(response.json()["parameters"])
        
        # ファイル名
        filePath = os.path.join(
            os.path.dirname(self.rootPath), 
            self.gv.StabdifspyConfig.outputDirName, 
            self.gv.StabdifspyConfig.outputFileNameFormat.format(int(time.time())))

        # 画像生成
        with open(filePath, "wb") as f:
            f.write(base64.b64decode(response.json()["images"][0]))

        # ファイルパスを返す
        return filePath
    
    def getPayload(self):
        """
        payload取得
        """

        return {
            "prompt":"line stamp, 1girl, solo, chain, Chibi, Half-smile, Santa Claus, comic, blue eyes, long hair, headphones, parted lips, black hair",
            "negative_prompt": "worst quality, large head, low quality, extra digits, bad eye, EasyNegativeV2, ng_deepnegative_v1_75t, text"
        }



__copyright__    = 'Copyright (C) 2023-2024 unchainworks'
__version__      = '1.0.5'
__license__      = 'BSD-3-Clause'
__author__       = 'unchainworks'
__author_email__ = 'kajin0318@gmail.com'
__url__          = 'https://github.com/kaioman/Stabdifspy.git'